@@ -204,7 +204,7 @@ pwquality_set_option(pwquality_settings_t *pwq, const char *option)
                 return PWQ_ERROR_UNKNOWN_SETTING;
 
         strncpy(name, option, len);
-        name[sizeof(name) - 1] = '\0';
+        name[len] = '\0';
 
         return set_name_value(pwq, name, value);
 }
@@ -245,6 +245,9 @@ pwquality_set_int_value(pwquality_settings_t *pwq, int setting, int value)
         case PWQ_SETTING_MAX_CLASS_REPEAT:
                 pwq->max_class_repeat = value;
                 break;
+        case PWQ_SETTING_MAX_SEQUENCE:
+                pwq->max_sequence = value;
+                break;
         case PWQ_SETTING_GECOS_CHECK:
                 pwq->gecos_check = value;
                 break;
